package miru.timereminder;

import java.util.ArrayList;
import java.util.List;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.net.Uri;

import miru.timereminder.ReminderDB.Reminder;

public class ReminderDBSupporter extends SQLiteOpenHelper {

	public static final int DATABASE_VERSION = 1;
    public static final String DATABASE_NAME = "reminder.db";
	
	private static final String SQL_CREATE_REMINDER = "CREATE TABLE " + Reminder.TABLE_NAME + " (" +
			Reminder._ID + " INTEGER PRIMARY KEY AUTOINCREMENT," +
			Reminder.COLUMN_NAME_REMINDER_NAME + " TEXT," +
			Reminder.COLUMN_NAME_REMINDER_TIME_HOUR + " INTEGER," +
			Reminder.COLUMN_NAME_REMINDER_TIME_MINUTE + " INTEGER," +
			Reminder.COLUMN_NAME_REMINDER_REPEAT_DAYS + " TEXT," +
			Reminder.COLUMN_NAME_REMINDER_REPEAT_WEEKLY + " BOOLEAN," +
			Reminder.COLUMN_NAME_REMINDER_TONE + " TEXT," +
			Reminder.COLUMN_NAME_REMINDER_ENABLED + " BOOLEAN" +
	    " )";
	
	private static final String SQL_DELETE_REMINDER =
		    "DROP TABLE IF EXISTS " + Reminder.TABLE_NAME;
    
	public ReminderDBSupporter(Context context) {
		super(context, DATABASE_NAME, null, DATABASE_VERSION);
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		db.execSQL(SQL_CREATE_REMINDER);
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		db.execSQL(SQL_DELETE_REMINDER);
        onCreate(db);
	}
	
	private ReminderModel populateModel(Cursor c) {
		ReminderModel model = new ReminderModel();
		model.id = c.getLong(c.getColumnIndex(Reminder._ID));
		model.name = c.getString(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_NAME));
		model.timeHour = c.getInt(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_TIME_HOUR));
		model.timeMinute = c.getInt(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_TIME_MINUTE));
		model.repeatWeekly = c.getInt(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_REPEAT_WEEKLY)) == 0 ? false : true;
		model.reminderTone = c.getString(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_TONE)) != "" ? Uri.parse(c.getString(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_TONE))) : null;
		model.isEnabled = c.getInt(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_ENABLED)) == 0 ? false : true;
		
		String[] repeatingDays = c.getString(c.getColumnIndex(Reminder.COLUMN_NAME_REMINDER_REPEAT_DAYS)).split(",");
		for (int i = 0; i < repeatingDays.length; ++i) {
			model.setRepeatingDay(i, repeatingDays[i].equals("false") ? false : true);
		}
		
		return model;
	}
	
	private ContentValues populateContent(ReminderModel model) {
		ContentValues values = new ContentValues();
        values.put(Reminder.COLUMN_NAME_REMINDER_NAME, model.name);
        values.put(Reminder.COLUMN_NAME_REMINDER_TIME_HOUR, model.timeHour);
        values.put(Reminder.COLUMN_NAME_REMINDER_TIME_MINUTE, model.timeMinute);
        values.put(Reminder.COLUMN_NAME_REMINDER_REPEAT_WEEKLY, model.repeatWeekly);
        values.put(Reminder.COLUMN_NAME_REMINDER_TONE, model.reminderTone != null ? model.reminderTone.toString() : "");
        values.put(Reminder.COLUMN_NAME_REMINDER_ENABLED, model.isEnabled);
        
        String repeatingDays = "";
        for (int i = 0; i < 7; ++i) {
        	repeatingDays += model.getRepeatingDay(i) + ",";
        }
        values.put(Reminder.COLUMN_NAME_REMINDER_REPEAT_DAYS, repeatingDays);
        
        return values;
	}
	
	public long createReminder(ReminderModel model) {
		ContentValues values = populateContent(model);
        return getWritableDatabase().insert(Reminder.TABLE_NAME, null, values);
	}
	
	public long updateReminder(ReminderModel model) {
		ContentValues values = populateContent(model);
        return getWritableDatabase().update(Reminder.TABLE_NAME, values, Reminder._ID + " = ?", new String[] { String.valueOf(model.id) });
	}
	
	public ReminderModel getReminder(long id) {
		SQLiteDatabase db = this.getReadableDatabase();
		
        String select = "SELECT * FROM " + Reminder.TABLE_NAME + " WHERE " + Reminder._ID + " = " + id;
		
		Cursor c = db.rawQuery(select, null);
		
		if (c.moveToNext()) {
			return populateModel(c);
		}
		
		return null;
	}
	
	public List<ReminderModel> getReminders() {
		SQLiteDatabase db = this.getReadableDatabase();
		
        String select = "SELECT * FROM " + Reminder.TABLE_NAME;
		
		Cursor c = db.rawQuery(select, null);
		
		List<ReminderModel> reminderList = new ArrayList<ReminderModel>();
		
		while (c.moveToNext()) {
			reminderList.add(populateModel(c));
		}
		
		if (!reminderList.isEmpty()) {
			return reminderList;
		}
		
		return null;
	}
	
	public int deleteReminder(long id) {
		return getWritableDatabase().delete(Reminder.TABLE_NAME, Reminder._ID + " = ?", new String[] { String.valueOf(id) });
	}
}
