package miru.timereminder;

import android.annotation.TargetApi;
import android.app.Activity;
import android.content.Intent;
import android.media.RingtoneManager;
import android.os.Build;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.TimePicker;

public class ReminderDetails extends Activity {
	
	private ReminderDBSupporter dbHelper = new ReminderDBSupporter(this);
	
	private ReminderModel reminderDetails;
	
	private TimePicker timePicker;
	private EditText edtName;
	private ReminderCustomSwitch chkWeekly;
	private ReminderCustomSwitch chkSunday;
	private ReminderCustomSwitch chkMonday;
	private ReminderCustomSwitch chkTuesday;
	private ReminderCustomSwitch chkWednesday;
	private ReminderCustomSwitch chkThursday;
	private ReminderCustomSwitch chkFriday;
	private ReminderCustomSwitch chkSaturday;
	private TextView txtToneSelection;
	
	@TargetApi(Build.VERSION_CODES.HONEYCOMB) @Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		requestWindowFeature(Window.FEATURE_ACTION_BAR);

		setContentView(R.layout.reminder_desc);

		getActionBar().setTitle("Create New Reminder");
		getActionBar().setDisplayHomeAsUpEnabled(true);
		
		timePicker = (TimePicker) findViewById(R.id.reminder_time_picker);
		edtName = (EditText) findViewById(R.id.reminder_name);
		chkWeekly = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_weekly);
		chkSunday = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_sunday);
		chkMonday = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_monday);
		chkTuesday = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_tuesday);
		chkWednesday = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_wednesday);
		chkThursday = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_thursday);
		chkFriday = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_friday);
		chkSaturday = (ReminderCustomSwitch) findViewById(R.id.reminder_repeat_saturday);
		txtToneSelection = (TextView) findViewById(R.id.reminder_label_tone_selection);
		
		long id = getIntent().getExtras().getLong("id");
		
		if (id == -1) {
			reminderDetails = new ReminderModel();
		} else {
			reminderDetails = dbHelper.getReminder(id);
			
			timePicker.setCurrentMinute(reminderDetails.timeMinute);
			timePicker.setCurrentHour(reminderDetails.timeHour);
			
			edtName.setText(reminderDetails.name);
			
			chkWeekly.setChecked(reminderDetails.repeatWeekly);
			chkSunday.setChecked(reminderDetails.getRepeatingDay(ReminderModel.SUNDAY));
			chkMonday.setChecked(reminderDetails.getRepeatingDay(ReminderModel.MONDAY));
			chkTuesday.setChecked(reminderDetails.getRepeatingDay(ReminderModel.TUESDAY));
			chkWednesday.setChecked(reminderDetails.getRepeatingDay(ReminderModel.WEDNESDAY));
			chkThursday.setChecked(reminderDetails.getRepeatingDay(ReminderModel.THURSDAY));
			chkFriday.setChecked(reminderDetails.getRepeatingDay(ReminderModel.FRDIAY));
			chkSaturday.setChecked(reminderDetails.getRepeatingDay(ReminderModel.SATURDAY));

			txtToneSelection.setText(RingtoneManager.getRingtone(this, reminderDetails.reminderTone).getTitle(this));
		}

		final LinearLayout ringToneContainer = (LinearLayout) findViewById(R.id.reminder_ringtone_container);
		ringToneContainer.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				Intent intent = new Intent(RingtoneManager.ACTION_RINGTONE_PICKER);
				startActivityForResult(intent , 1);
			}
		});
	}
	
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		
		if (resultCode == RESULT_OK) {
	        switch (requestCode) {
		        case 1: {
		        	reminderDetails.reminderTone = data.getParcelableExtra(RingtoneManager.EXTRA_RINGTONE_PICKED_URI);
		        	txtToneSelection.setText(RingtoneManager.getRingtone(this, reminderDetails.reminderTone).getTitle(this));
		            break;
		        }
		        default: {
		            break;
		        }
	        }
	    }
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.reminder_desc, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {

		switch (item.getItemId()) {
			case android.R.id.home: {
				finish();
				break;
			}
			case R.id.action_save_reminder_details: {
				updateModelFromLayout();
				
				ReminderHelper.cancelReminders(this);
				
				if (reminderDetails.id < 0) {
					dbHelper.createReminder(reminderDetails);
				} else {
					dbHelper.updateReminder(reminderDetails);
				}
				
				ReminderHelper.setReminders(this);
				
				setResult(RESULT_OK);
				finish();
			}
		}

		return super.onOptionsItemSelected(item);
	}
	
	private void updateModelFromLayout() {		
		reminderDetails.timeMinute = timePicker.getCurrentMinute().intValue();
		reminderDetails.timeHour = timePicker.getCurrentHour().intValue();
		reminderDetails.name = edtName.getText().toString();
		reminderDetails.repeatWeekly = chkWeekly.isChecked();	
		reminderDetails.setRepeatingDay(ReminderModel.SUNDAY, chkSunday.isChecked());	
		reminderDetails.setRepeatingDay(ReminderModel.MONDAY, chkMonday.isChecked());	
		reminderDetails.setRepeatingDay(ReminderModel.TUESDAY, chkTuesday.isChecked());
		reminderDetails.setRepeatingDay(ReminderModel.WEDNESDAY, chkWednesday.isChecked());	
		reminderDetails.setRepeatingDay(ReminderModel.THURSDAY, chkThursday.isChecked());
		reminderDetails.setRepeatingDay(ReminderModel.FRDIAY, chkFriday.isChecked());
		reminderDetails.setRepeatingDay(ReminderModel.SATURDAY, chkSaturday.isChecked());
		reminderDetails.isEnabled = true;
	}
	
}
