package miru.timereminder;

import java.util.Calendar;
import java.util.List;

import android.annotation.SuppressLint;
import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;

public class ReminderHelper extends BroadcastReceiver {

	public static final String ID = "id";
	public static final String NAME = "name";
	public static final String TIME_HOUR = "timeHour";
	public static final String TIME_MINUTE = "timeMinute";
	public static final String TONE = "reminderTone";
	
	@Override
	public void onReceive(Context context, Intent intent) {
		setReminders(context);
	}
	
	public static void setReminders(Context context) {
		cancelReminders(context);
		
		ReminderDBSupporter dbHelper = new ReminderDBSupporter(context);

		List<ReminderModel> reminders =  dbHelper.getReminders();
		
		for (ReminderModel reminder : reminders) {
			if (reminder.isEnabled) {

				PendingIntent pIntent = createPendingIntent(context, reminder);

				Calendar calendar = Calendar.getInstance();
				calendar.set(Calendar.HOUR_OF_DAY, reminder.timeHour);
				calendar.set(Calendar.MINUTE, reminder.timeMinute);
				calendar.set(Calendar.SECOND, 00);

				//Find next time to set
				final int nowDay = Calendar.getInstance().get(Calendar.DAY_OF_WEEK);
				final int nowHour = Calendar.getInstance().get(Calendar.HOUR_OF_DAY);
				final int nowMinute = Calendar.getInstance().get(Calendar.MINUTE);
				boolean reminderSet = false;
				
				//First check if it's later in the week
				for (int dayOfWeek = Calendar.SUNDAY; dayOfWeek <= Calendar.SATURDAY; ++dayOfWeek) {
					if (reminder.getRepeatingDay(dayOfWeek - 1) && dayOfWeek >= nowDay &&
							!(dayOfWeek == nowDay && reminder.timeHour < nowHour) &&
							!(dayOfWeek == nowDay && reminder.timeHour == nowHour && reminder.timeMinute <= nowMinute)) {
						calendar.set(Calendar.DAY_OF_WEEK, dayOfWeek);
						
						setReminder(context, calendar, pIntent);
						reminderSet = true;
						break;
					}
				}
				
				//Else check if it's earlier in the week
				if (!reminderSet) {
					for (int dayOfWeek = Calendar.SUNDAY; dayOfWeek <= Calendar.SATURDAY; ++dayOfWeek) {
						if (reminder.getRepeatingDay(dayOfWeek - 1) && dayOfWeek <= nowDay && reminder.repeatWeekly) {
							calendar.set(Calendar.DAY_OF_WEEK, dayOfWeek);
							calendar.add(Calendar.WEEK_OF_YEAR, 1);
							
							setReminder(context, calendar, pIntent);
							reminderSet = true;
							break;
						}
					}
				}
			}
		}
	}
	
	@SuppressLint("NewApi")
	private static void setReminder(Context context, Calendar calendar, PendingIntent pIntent) {
		AlarmManager alarmManager = (AlarmManager) context.getSystemService(Context.ALARM_SERVICE);
		if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.KITKAT) {
			alarmManager.setExact(AlarmManager.RTC_WAKEUP, calendar.getTimeInMillis(), pIntent);
		} else {
			alarmManager.set(AlarmManager.RTC_WAKEUP, calendar.getTimeInMillis(), pIntent);
		}
	}
	
	public static void cancelReminders(Context context) {
		ReminderDBSupporter dbHelper = new ReminderDBSupporter(context);
		
		List<ReminderModel> reminders =  dbHelper.getReminders();
		
 		if (reminders != null) {
			for (ReminderModel reminder : reminders) {
				if (reminder.isEnabled) {
					PendingIntent pIntent = createPendingIntent(context, reminder);
	
					AlarmManager alarmManager = (AlarmManager) context.getSystemService(Context.ALARM_SERVICE);
					alarmManager.cancel(pIntent);
				}
			}
 		}
	}

	private static PendingIntent createPendingIntent(Context context, ReminderModel model) {
		Intent intent = new Intent(context, ReminderServices.class);
		intent.putExtra(ID, model.id);
		intent.putExtra(NAME, model.name);
		intent.putExtra(TIME_HOUR, model.timeHour);
		intent.putExtra(TIME_MINUTE, model.timeMinute);
		intent.putExtra(TONE, model.reminderTone.toString());
		
		return PendingIntent.getService(context, (int) model.id, intent, PendingIntent.FLAG_UPDATE_CURRENT);
	}
}
