package miru.timereminder;

import android.app.AlertDialog;
import android.app.ListActivity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.Window;

public class ReminderList extends ListActivity {

	private ReminderListAdapter mAdapter;
	private ReminderDBSupporter dbHelper = new ReminderDBSupporter(this);
	private Context mContext;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		mContext = this;
		
		requestWindowFeature(Window.FEATURE_ACTION_BAR);
		
		setContentView(R.layout.reminder_list);

		mAdapter = new ReminderListAdapter(this, dbHelper.getReminders());
		
		setListAdapter(mAdapter);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.reminder_form_list, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {

		switch (item.getItemId()) {
			case R.id.action_add_new_reminder: {
				startReminderDetailsActivity(-1);
				break;
			}
		}

		return super.onOptionsItemSelected(item);
	}
	
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		
		if (resultCode == RESULT_OK) {
	        mAdapter.setReminders(dbHelper.getReminders());
	        mAdapter.notifyDataSetChanged();
	    }
	}
	
	public void setReminderEnabled(long id, boolean isEnabled) {
		ReminderHelper.cancelReminders(this);
		
		ReminderModel model = dbHelper.getReminder(id);
		model.isEnabled = isEnabled;
		dbHelper.updateReminder(model);
		
		ReminderHelper.setReminders(this);
	}

	public void startReminderDetailsActivity(long id) {
		Intent intent = new Intent(this, ReminderDetails.class);
		intent.putExtra("id", id);
		startActivityForResult(intent, 0);
	}
	
	public void deleteReminder(long id) {
		final long reminderId = id;
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		builder.setMessage("Please confirm")
		.setTitle("Delete set?")
		.setCancelable(true)
		.setNegativeButton("Cancel", null)
		.setPositiveButton("Ok", new OnClickListener() {
			
	@Override
			public void onClick(DialogInterface dialog, int which) {
				//Cancel Alarms
				ReminderHelper.cancelReminders(mContext);
				//Delete alarm from DB by id
				dbHelper.deleteReminder(reminderId);
				//Refresh the list of the alarms in the adaptor
				mAdapter.setReminders(dbHelper.getReminders());
				//Notify the adapter the data has changed
				mAdapter.notifyDataSetChanged();
				//Set the alarms
				ReminderHelper.setReminders(mContext);
			}
		}).show();
	}
}
