package miru.timereminder;

import java.util.List;
import android.content.Context;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.View.OnLongClickListener;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.TextView;
import android.widget.ToggleButton;

public class ReminderListAdapter extends BaseAdapter {

	private Context mContext;
	private List<ReminderModel> mReminders;

	public ReminderListAdapter(Context context, List<ReminderModel> reminders) {
		mContext = context;
		mReminders = reminders;
	}
	
	public void setReminders(List<ReminderModel> reminders) {
		mReminders = reminders;
	}
	
	@Override
	public int getCount() {
		if (mReminders != null) {
			return mReminders.size();
		}
		return 0;
	}

	@Override
	public Object getItem(int position) {
		if (mReminders != null) {
			return mReminders.get(position);
		}
		return null;
	}

	@Override
	public long getItemId(int position) {
		if (mReminders != null) {
			return mReminders.get(position).id;
		}
		return 0;
	}
	

	@Override
	public View getView(int position, View view, ViewGroup parent) {

		if (view == null) {
			LayoutInflater inflater = (LayoutInflater) mContext.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
			view = inflater.inflate(R.layout.reminder_item_list, parent, false);
		}
		
		ReminderModel model = (ReminderModel) getItem(position);
		
		TextView txtTime = (TextView) view.findViewById(R.id.reminder_item_time);
		txtTime.setText(String.format("%02d : %02d", model.timeHour, model.timeMinute));
		
		TextView txtName = (TextView) view.findViewById(R.id.reminder_item_name);
		txtName.setText(model.name);

		updateTextColor((TextView) view.findViewById(R.id.reminder_item_sunday), model.getRepeatingDay(ReminderModel.SUNDAY));
		updateTextColor((TextView) view.findViewById(R.id.reminder_item_monday), model.getRepeatingDay(ReminderModel.MONDAY));
		updateTextColor((TextView) view.findViewById(R.id.reminder_item_tuesday), model.getRepeatingDay(ReminderModel.TUESDAY));
		updateTextColor((TextView) view.findViewById(R.id.reminder_item_wednesday), model.getRepeatingDay(ReminderModel.WEDNESDAY));
		updateTextColor((TextView) view.findViewById(R.id.reminder_item_thursday), model.getRepeatingDay(ReminderModel.THURSDAY));
		updateTextColor((TextView) view.findViewById(R.id.reminder_item_friday), model.getRepeatingDay(ReminderModel.FRDIAY));		
		updateTextColor((TextView) view.findViewById(R.id.reminder_item_saturday), model.getRepeatingDay(ReminderModel.SATURDAY));
		
		ToggleButton btnToggle = (ToggleButton) view.findViewById(R.id.reminder_item_toggle);
		btnToggle.setChecked(model.isEnabled);
		btnToggle.setTag(Long.valueOf(model.id));
		btnToggle.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
				((ReminderList) mContext).setReminderEnabled(((Long) buttonView.getTag()).longValue(), isChecked);
			}
		});
		
		view.setTag(Long.valueOf(model.id));
		view.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View view) {
				((ReminderList) mContext).startReminderDetailsActivity(((Long) view.getTag()).longValue());
			}
		});
		
		view.setOnLongClickListener(new OnLongClickListener() {
			
			@Override
			public boolean onLongClick(View view) {
				((ReminderList) mContext).deleteReminder(((Long) view.getTag()).longValue());
				return true;
			}
		});
		
		return view;
	}
	
	private void updateTextColor(TextView view, boolean isOn) {
		if (isOn) {
			view.setTextColor(Color.GREEN);
		} else {
			view.setTextColor(Color.BLACK);
		}
	}

}
